Index: /CKEditor/branches/features/paste/_source/core/htmlparser/comment.js
===================================================================
--- /CKEditor/branches/features/paste/_source/core/htmlparser/comment.js	(revision 4763)
+++ /CKEditor/branches/features/paste/_source/core/htmlparser/comment.js	(revision 4764)
@@ -45,5 +45,5 @@
 		if ( filter )
 		{
-			if ( !( comment = filter.onComment( comment ) ) )
+			if ( !( comment = filter.onComment( comment, this ) ) )
 				return;
 
Index: /CKEditor/branches/features/paste/_source/core/htmlparser/filter.js
===================================================================
--- /CKEditor/branches/features/paste/_source/core/htmlparser/filter.js	(revision 4763)
+++ /CKEditor/branches/features/paste/_source/core/htmlparser/filter.js	(revision 4764)
@@ -67,8 +67,8 @@
 			},
 
-			onComment : function( commentText )
+			onComment : function( commentText, comment )
 			{
 				var textFilter = this._.comment;
-				return textFilter ? textFilter.filter( commentText ) : commentText;
+				return textFilter ? textFilter.filter( commentText, comment ) : commentText;
 			},
 
Index: /CKEditor/branches/features/paste/_source/plugins/pastefromword/filter/default.js
===================================================================
--- /CKEditor/branches/features/paste/_source/plugins/pastefromword/filter/default.js	(revision 4763)
+++ /CKEditor/branches/features/paste/_source/plugins/pastefromword/filter/default.js	(revision 4764)
@@ -821,13 +821,4 @@
 							firstChild = children && children[ 0 ];
 
-						if ( firstChild && firstChild.name == 'cke:imagesource' )
-						{
-							var secondChild = children[ 1 ];
-							if ( 'img' == secondChild.name )
-								secondChild.attributes.src = firstChild.attributes.src;
-							children.splice( 0, 1 );
-							delete element.name;
-						}
-
 						// Assume MS-Word mostly carry font related styles on <span>,
 						// adapting them to editor's convention.
@@ -873,4 +864,6 @@
 					// Remove onmouseover and onmouseout events (from MS Word comments effect)
 					[ /^onmouse(:?out|over)/, '' ],
+					// Onload on image element.
+					[ /^onload$/, '' ],
 					// Remove office and vml attribute from elements.
 					[ /(?:v|o):\w+/, '' ],
@@ -960,13 +953,19 @@
 						{
 							var imageInfo = value.match( /<img.*?>/ ),
-								imageSource = value.match( /<v:imagedata[^>]*o:href=['"](.*?)['"]/ ),
 								listInfo = value.match( /^\[if !supportLists\]([\s\S]*?)\[endif\]$/ );
 
 							// Reveal the <img> element in conditional comments for Firefox.
 							if( CKEDITOR.env.gecko && imageInfo )
-								return CKEDITOR.htmlParser.fragment.fromHtml( imageInfo[ 0 ] ).children[ 0 ];
-							// Try to dig the real image link from vml markup.
-							if( imageSource )
-								return new CKEDITOR.htmlParser.element( 'cke:imagesource', { src : imageSource[ 1 ] } );
+							{
+								var img = CKEDITOR.htmlParser.fragment.fromHtml( imageInfo[ 0 ] ).children[ 0 ],
+									previousComment = node.previous,
+									// Try to dig the real image link from vml markup from previous comment text.
+									imgSrcInfo = previousComment.value.match( /<v:imagedata[^>]*o:href=['"](.*?)['"]/ ),
+									imgSrc = imgSrcInfo && imgSrcInfo[ 1 ];
+
+								imgSrc && ( img.attributes.src = imgSrc );
+								return img;
+							}
+
 							// Seek for list bullet style indicator.
 							if ( listInfo )
@@ -976,4 +975,5 @@
 								return createListBulletMarker( listType, listSymbol );
 							}
+
 							return false;
 						} 
